@@ -21,6 +21,10 @@ sub abstract {
     return 'Download satellite orbital elements from Space Track';
 }
 
+sub add_to_cleanup {
+    return [ qw{ cover_db xt/author/optionals } ];
+}
+
 sub author {
     return 'Tom Wyant (wyant at cpan dot org)';
 }
@@ -188,6 +192,10 @@ sub script_files {
     ];
 }
 
+sub version_from {
+    return 'lib/Astro/SpaceTrack.pm';
+}
+
 1;
 
 __END__
@@ -226,6 +234,11 @@ This method instantiates the class.
 
 This method returns the distribution's abstract.
 
+=head2 add_to_cleanup
+
+This method returns a reference to an array of files to be added to the
+cleanup.
+
 =head2 author
 
 This method returns the name of the distribution author
@@ -333,6 +346,11 @@ This method returns the version of Perl required by the package.
 This method returns a reference to an array containing the names of
 script files provided by this distribution. This array may be empty.
 
+=head2 version_from
+
+This method returns the name of the distribution file from which the
+distribution's version is to be derived.
+
 =head1 ATTRIBUTES
 
 This class has no public attributes.
